# PythonPals

## Usage
`This project is a game intended to teach new programmers basic concepts of the Python language in an
engaging, 2D battle. Players will choose which concepts they would like to review (e.g. syntax, logic,
number conversion) and then enter a battle scene where they will be asked multiple-choice questions and
be expected to provide the correct answer. A correct answer deals damage to the opponent while an
incorrect answer reduces the player's own HP. The player wins when their opponent's HP reaches zero and
the player loses if their own HP reaches zero. While the initial project will have preset questions
relating to Python, we will be adding functionality allowing users to create their own question decks
for use in a variety of fields.`

`**Note about bugs: In the current version of PythonPals, the window resize function has unintended effects on the functionality of the battle scene. To avoid glitching in the battle scene display, do not resize the game window unless in the main menu screen. In addition, in the questions menu within the battle scene, some of the longer questions have been cut off instead of continuing to the next line. For now, the readability of the majority of the questions has been prioritized over displaying the entirety of the longer ones. Lastly, the 'Options' button in the main menu, meant to change certain settings and let the user enter their own questions, currently has no functionality as it would serve no purpose at this stage.`

## Package name for PIP installation
pip install . from PythonPals directory
pip install PythonPals

## Run executable command 
python-pals

## GitHub repository:
https://github.com/nathanhilton/PythonPals/tree/development
